/* ============================================================================
 *                          u a r t _ i n t e r f a c e . c
 * ============================================================================
 * Cytonome CAB 3.0 Cypress CY8C5868AXI-LP035 Firmware
 * Copyright Cytonome ST, LLC 2022
 * All Rights Reserved
 *
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Cytonome ST, LLC.
 
 * Revision History:
 *  001 6 Jun 22 <sek> created
 *  002 13 Jun 22 <sek> changed TRANSMIT_BUFFER_SIZE to 80
 *  003 14 Jul 22 <sek> uart_put_time()
 *  004 24 Jan 23 <sek> ARRAY markers, removed fg_TransmitBuffer[]
 *
 * ============================================================================
 */

#include "gsfstd.h"

#include <project.h>
#include "stdio.h"
#include "stdlib.h"
#include <uart_interface.h>


/* Variable to store ADC result */
uint32 fg_Output;

/* Variable used to send emulated data */
uint8 fg_EmulatedData;
/* Flags used to store transmit data commands */
uint8 fg_ContinuouslySendData;
uint8 fg_SendSingleByte;
uint8 fg_SendEmulatedData;


void uart_initialize(void)
{
    /* Start communications */
    UART_Start();
    
    /* Initialize Variables */
    fg_ContinuouslySendData = FALSE;
    fg_SendSingleByte = FALSE;
    fg_SendEmulatedData = FALSE;
    fg_EmulatedData = 0;
     
    /* Send message to verify COM port is connected properly */
    UART_PutString("\r\n\r\nCOM Port Open\r\n");
//    UART_PutString("Press C, S, X, E \r\n");

}

void Uart_check_input(void)
{
    /* Variable to store UART received character */
    uint8 Ch;
    
    /* Non-blocking call to get the latest data recieved  */
    Ch = UART_GetChar();

    /* Set flags based on UART command */
    switch(Ch)
    {
        case 0:
            /* No new data was recieved */
            break;
        case 'C':
        case 'c':
            fg_SendSingleByte = TRUE;
            break;
        case 'S':
        case 's':
            fg_ContinuouslySendData = TRUE;
            break;
        case 'X':
        case 'x':
            fg_ContinuouslySendData = FALSE;
            break;
        case 'E':
        case 'e':
            fg_SendEmulatedData = TRUE;
            break;
        default:
            /* Place error handling code here */
            break;    
    }

}

void uart_put_string(char *str)
{
    /* Send out the data */
    UART_PutString(str);
}

void uart_put_line(char *str)
{
    /* Send out the data */
    UART_PutString(str);
    UART_PutString(" \r\n");
    
}

void uart_put_char(char ch)
{
    /* Send out the data */
    UART_PutChar(ch);
}


void uart_put_time(uint32 time)
{

    ARRAY char tstr[16];  // Stores string for UART use.

    // Timing and time, started at 0.
    //
    int seconds = 0;
    int minutes = 0;
    int hours   = 0;
    
    // Every second, update the TOP row of
    // the LCD display. Break down time to 
    // hours/minutes/seconds
    // 
    hours   = SECONDS_TIME_TO_HOURS(time);  
    minutes = SECONDS_TIME_TO_MINUTES(time);
    seconds = SECONDS_TIME_TO_SECONDS(time);

    uart_put_string("Elapsed Time ");
    
    if ( hours < 10 )
    {
        uart_put_string("0");
    }
    sprintf(tstr, "%d:", hours);
    uart_put_string(tstr);
    
    if ( minutes < 10 )
    {
        uart_put_string("0");
    }
    sprintf(tstr, "%d:", minutes);
    uart_put_string(tstr);

    if ( seconds < 10 )
    {
        uart_put_string("0");
    }
    sprintf(tstr, "%d", seconds);
    uart_put_line(tstr);

}


// end of file
